@@ -2,11 +2,10 @@
 """
 
 from raider.__version__ import __version__
-from raider.application import Application
-from raider.authentication import Authentication
 from raider.config import Config
 from raider.flow import Flow
-from raider.functions import Functions
+from raider.flowstore import FlowStore
+from raider.projects import Project
 from raider.raider import Raider
 from raider.request import Request
 from raider.user import User
