@@ -16,7 +16,6 @@
 """Operations performed on Flows after the response is received.
 """
 
-import logging
 import re
 import sys
 from functools import partial
@@ -25,9 +24,11 @@ from typing import Any, Callable, List, Optional, Union
 import requests
 
 from raider.plugins.common import Plugin
+from raider.utils import colored_text
 
 
 def execute_actions(
+    pconfig,
     operations: Union["Operation", List["Operation"]],
     response: requests.models.Response,
 ) -> Optional[str]:
@@ -36,7 +37,7 @@ def execute_actions(
     In order to allow multiple Operations to be run inside the "action"
     and "otherwise" attributes lists of Operations are accepted. The
     execution will stop if one of the Operations returns a string, to
-    indicate the next stage has been decided.
+    indicate the next flow has been decided.
 
     Args:
       operations:
@@ -46,15 +47,15 @@ def execute_actions(
         might be needed to run the Operation.
 
     Returns:
-      A string with the name of the next stage to be run, or None.
+      A string with the name of the next flow to be run, or None.
 
     """
     if isinstance(operations, Operation):
-        return operations.run(response)
+        return operations.run(pconfig, response)
 
     if isinstance(operations, list):
         for item in operations:
-            output = item.run(response)
+            output = item.run(pconfig, response)
             if output:
                 return output
 
@@ -96,9 +97,12 @@ class Operation:
     # Operation's function needs the HTTP response to run.
     NEEDS_RESPONSE = 0x02
 
+    # Operation uses plugins with userdata
+    NEEDS_USERDATA = 0x04
+
     # Operation will append instead of overwrite. Used when dealing with files
     # to make sure old data doesn't get overwritten.
-    WILL_APPEND = 0x04
+    WILL_APPEND = 0x08
 
     def __init__(
         self,
@@ -127,8 +131,10 @@ class Operation:
         self.flags = flags
         self.action = action
         self.otherwise = otherwise
+        self.pconfig = None
+        self.logger = None
 
-    def run(self, response: requests.models.Response) -> Optional[str]:
+    def run(self, pconfig, response: requests.models.Response) -> Optional[str]:
         """Runs the Operation.
 
         Runs the defined Operation, considering the "flags" set.
@@ -139,16 +145,26 @@ class Operation:
             be passed to the operation's "function".
 
         Returns:
-          An optional string with the name of the next stage.
+          An optional string with the name of the next flow.
 
         """
-        logging.debug("Running operation %s", str(self))
+        self.pconfig = pconfig
+        self.logger = self.pconfig.logger
+
+        self.logger.debug("Running operation %s", str(self))
+        if self.needs_userdata:
+            self.get_plugin_values()
         if self.is_conditional:
             return self.run_conditional(response)
         if self.needs_response:
             return self.function(response)
         return self.function()
 
+    def get_plugin_values(self):
+        for item in self.args:
+            if isinstance(item, Plugin):
+                item.get_value(self.pconfig)
+
     def run_conditional(
         self, response: requests.models.Response
     ) -> Optional[str]:
@@ -164,7 +180,7 @@ class Operation:
             be passed to the operation's "function".
 
         Returns:
-          An optional string with the name of the next stage.
+          An optional string with the name of the next flow.
 
         """
         if self.needs_response:
@@ -173,9 +189,9 @@ class Operation:
             check = self.function()
 
         if check and self.action:
-            return execute_actions(self.action, response)
+            return execute_actions(self.pconfig, self.action, response)
         if self.otherwise:
-            return execute_actions(self.otherwise, response)
+            return execute_actions(self.pconfig, self.otherwise, response)
 
         return None
 
@@ -184,6 +200,11 @@ class Operation:
         """Returns True if the NEEDS_RESPONSE flag is set."""
         return bool(self.flags & self.NEEDS_RESPONSE)
 
+    @property
+    def needs_userdata(self) -> bool:
+        """Returns True if the NEEDS_USERDATA flag is set."""
+        return bool(self.flags & self.NEEDS_USERDATA)
+
     @property
     def is_conditional(self) -> bool:
         """Returns True if the IS_CONDITIONAL flag is set."""
@@ -321,6 +342,55 @@ class Grep(Operation):
         )
 
 
+class Match(Operation):
+    def __init__(
+        self,
+        match1: Union[str, Plugin],
+        match2: Union[str, Plugin],
+        action: Operation,
+        otherwise: Optional[Operation] = None,
+    ) -> None:
+        self.args = (match1, match2)
+        super().__init__(
+            function=self.check_match,
+            action=action,
+            otherwise=otherwise,
+            flags=Operation.IS_CONDITIONAL | Operation.NEEDS_USERDATA
+        )
+
+    def check_match(self) -> bool:
+        if isinstance(self.args[0], Plugin):
+            value1 = self.args[0].value
+        else:
+            value1 = self.args[0]
+
+        if isinstance(self.args[1], Plugin):
+            value2 = self.args[1].value
+        else:
+            value2 = self.args[1]
+
+        return (value1 == value2)
+            
+
+    def __str__(self) -> str:
+        """Returns a string representation of the Operation."""
+        return (
+            "(Match:"
+            + str(self.args[0])
+            + ","
+            + str(self.args[1])
+            + "="
+            + str(self.action)
+            + "/"
+            + str(self.otherwise)
+            + ")"
+        )
+
+
+
+
+
+
 class Save(Operation):
     """Operation to save information to files.
 
@@ -461,7 +531,7 @@ class Print(Operation):
     def __init__(
         self,
         *args: Union[str, Plugin],
-        flags: int = 0,
+        flags: int = Operation.NEEDS_USERDATA,
         function: Callable[..., Any] = None,
     ):
         """Initializes the Print Operation.
@@ -488,7 +558,11 @@ class Print(Operation):
             if isinstance(item, str):
                 print(item)
             else:
-                print(item.name + " = " + str(item.value))
+                print(
+                    colored_text(
+                        item.name + " = " + str(item.value), "YELLOW-BLACK-B"
+                    )
+                )
 
     def __str__(self) -> str:
         """Returns a string representation of the Print Operation."""
@@ -499,7 +573,8 @@ class Print(Operation):
         """Classmethod to print the HTTP response body."""
         operation = cls(
             function=lambda response: print(
-                "\nHTTP response body:\n" + response.text
+                colored_text("\nHTTP response body:\n", "YELLOW-BLACK-B")
+                + colored_text(response.text, "YELLOW-GRAY")
             ),
             flags=Operation.NEEDS_RESPONSE,
         )
@@ -532,16 +607,30 @@ class Print(Operation):
 
             """
 
-            print("HTTP response headers:")
+            print(colored_text("HTTP response headers:", "YELLOW-BLACK-B"))
 
             if headers:
                 for header in headers:
                     value = response.headers.get(header)
                     if value:
-                        print(": ".join([header, value]))
+                        print(
+                            ": ".join(
+                                [
+                                    colored_text(header, "CYAN-BLACK-B"),
+                                    colored_text(value, "BLUE-BLACK-B"),
+                                ]
+                            )
+                        )
             else:
                 for name, value in response.headers.items():
-                    print(": ".join([name, value]))
+                    print(
+                        ": ".join(
+                            [
+                                colored_text(name, "CYAN-BLACK-B"),
+                                colored_text(value, "BLUE-BLACK-B"),
+                            ]
+                        )
+                    )
 
         operation = cls(
             function=partial(print_headers, headers=headers),
@@ -574,16 +663,30 @@ class Print(Operation):
 
             """
 
-            print("HTTP response cookies:")
+            print(colored_text("HTTP response cookies:", "YELLOW-BLACK-B"))
 
             if cookies:
                 for cookie in cookies:
                     value = response.cookies.get(cookie)
                     if value:
-                        print(": ".join([cookie, value]))
+                        print(
+                            ": ".join(
+                                [
+                                    colored_text(cookie, "CYAN-BLACK-B"),
+                                    colored_text(value, "BLUE-BLACK-B"),
+                                ]
+                            )
+                        )
             else:
                 for name, value in response.cookies.items():
-                    print(": ".join([name, value]))
+                    print(
+                        ": ".join(
+                            [
+                                colored_text(name, "CYAN-BLACK-B"),
+                                colored_text(value, "BLUE-BLACK-B"),
+                            ]
+                        )
+                    )
 
         operation = cls(
             function=partial(print_cookies, cookies=cookies),
@@ -592,57 +695,86 @@ class Print(Operation):
         return operation
 
 
-class Error(Operation):
-    """Operation that will exit Raider and print the error message.
+class Failure(Operation):
+    """Operation that will signal a Failure in the process.
 
     Attributes:
       message:
-        A string with the error message to be printed.
+        An optional string with the error message to be printed.
     """
 
-    def __init__(self, message: str) -> None:
+    def __init__(self, message: str = None) -> None:
         """Initializes the Error Operation.
 
         Args:
           message:
-            A string with the error message to be displayed.
+            An optional string with the error message to be displayed.
         """
         self.message = message
-        super().__init__(
-            function=lambda: sys.exit(self.message),
-        )
+        super().__init__(function=self.return_failure)
+
+    def return_failure(self):
+        self.logger.error("Failure: " + str(self.message))
+        return False
 
     def __str__(self) -> str:
         """Returns a string representation of the Operation."""
-        return "(Error:" + str(self.message) + ")"
+        return "(Failure:" + str(self.message) + ")"
 
 
-class NextStage(Operation):
-    """Operation defining the next stage.
+class Success(Operation):
+    """Operation that will signal a Success in the process.
 
-    Inside the Authentication object NextStage is used to define the
+    Attributes:
+      message:
+        An optional string with the message to be printed.
+    """
+
+    def __init__(self, message: str = None) -> None:
+        """Initializes the Success Operation.
+
+        Args:
+          message:
+            An optional string with the message to be displayed.
+        """
+        self.message = message
+        super().__init__(function=self.return_success)
+
+    def return_success(self):
+        self.logger.info("Success: " + str(self.message))
+        return True
+
+    def __str__(self) -> str:
+        """Returns a string representation of the Operation."""
+        return "(Success:" + str(self.message) + ")"
+
+
+class Next(Operation):
+    """Operation defining the next flow.
+
+    Inside the Authentication object Next is used to define the
     next step of the authentication process. It can also be used inside
     "action" attributes of the other Operations to allow conditional
     decision making.
 
     Attributes:
-      next_stage:
-        A string with the name of the next stage to be executed.
+      next_flow:
+        A string with the name of the next flow to be executed.
 
     """
 
-    def __init__(self, next_stage: Optional[str]) -> None:
-        """Initializes the NextStage Operation.
+    def __init__(self, next_flow: Optional[str]) -> None:
+        """Initializes the Next Operation.
 
         Args:
-          next_stage:
-            A string with the name of the next stage.
+          next_flow:
+            A string with the name of the next flow.
         """
-        self.next_stage = str(next_stage)
+        self.next_flow = str(next_flow)
         super().__init__(
-            function=lambda: self.next_stage,
+            function=lambda: self.next_flow,
         )
 
     def __str__(self) -> str:
         """Returns a string representation of the Operation."""
-        return "(NextStage:" + self.next_stage + ")"
+        return "(Next:" + self.next_flow + ")"
