@@ -22,7 +22,7 @@ from urllib.parse import parse_qs, urlsplit
 from raider.plugins.common import Parser, Plugin
 
 
-class UrlParser(Parser):
+class Urlparser(Parser):
     """Parse the URL and extract elements from it.
 
     Use this when needing to extract some piece of information from
@@ -42,10 +42,12 @@ class UrlParser(Parser):
         def get_query(query: Union[str, bytes], element: str) -> str:
             """Extracts a parameter from the URL query."""
             key = element.split(".")[1]
-            return parse_qs(str(query))[key][0]
+            parsed_query = parse_qs(str(query))
+            if key in parsed_query:
+                return parsed_query[key][0]
+            return None
 
         value: Optional[str] = None
-
         self.url = self.plugins[0].value
         parsed_url = urlsplit(self.url)
 
