@@ -15,10 +15,12 @@
 
 """Data structures used in Raider.
 """
-
 from typing import Any, Dict, Iterator, List, Optional, Tuple
 
-from raider.plugins.basic import Cookie, Header
+import igraph
+
+from raider.plugins.basic.cookie import Cookie
+from raider.plugins.basic.header import Header
 
 
 class DataStore:
@@ -78,11 +80,11 @@ class DataStore:
         """Pops an element from the DataStore."""
         return self._store.pop(name)
 
-    def list_keys(self) -> List[Any]:
+    def keys(self) -> List[Any]:
         """Returns a list of the keys in the DataStore."""
         return list(self._store)
 
-    def list_values(self) -> List[Any]:
+    def values(self) -> List[Any]:
         """Returns a list of the values in the DataStore."""
         data = []
         for key in self._store:
